@@ -30,7 +30,6 @@
 #include <QApplication>
 #include <QDebug>
 #include <QDrag>
-#include <QFile>
 #include <QMimeData>
 #include <QPixmap>
 #include <QDropEvent>
@@ -43,7 +42,7 @@
 KWalletFolderItem::KWalletFolderItem(KWallet::Wallet *w, QTreeWidget *parent, const QString &name, int entries)
     : QTreeWidgetItem(parent, KWalletFolderItemClass), _wallet(w), _name(name), _entries(entries)
 {
-    setText(0, QString::fromLatin1("%1 (%2)").arg(_name).arg(_entries));
+    setText(0, QStringLiteral("%1 (%2)").arg(_name).arg(_entries));
     setFlags(Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled | Qt::ItemIsEnabled);
     setIcon(0, getFolderIcon(KIconLoader::Small));
 }
@@ -52,11 +51,11 @@ QPixmap KWalletFolderItem::getFolderIcon(KIconLoader::Group group)
 {
     QPixmap pix = QIcon::fromTheme(_name).pixmap(IconSize(group), IconSize(group));
 
-    if (pix.isNull())
+    if (pix.isNull()) {
         pix = QIcon::fromTheme(_name.toLower()).pixmap(IconSize(group), IconSize(group));
-
-    if (pix.isNull())
-        pix = QIcon::fromTheme(QLatin1String("folder-red")).pixmap(IconSize(group), IconSize(group));
+        if (pix.isNull())
+            pix = QIcon::fromTheme(QStringLiteral("folder-red")).pixmap(IconSize(group), IconSize(group));
+    }
 
     return pix;
 }
@@ -65,7 +64,7 @@ void KWalletFolderItem::refresh()
 {
     const QString saveFolder = _wallet->currentFolder();
     _wallet->setFolder(_name);
-    setText(0, QString::fromLatin1("%1 (%2)").arg(_name).arg(_wallet->entryList().count()));
+    setText(0, QStringLiteral("%1 (%2)").arg(_name).arg(_wallet->entryList().count()));
     _wallet->setFolder(saveFolder);
 }
 
@@ -83,7 +82,7 @@ void KWalletFolderItem::refreshItemsCount()
             }
         }
     }
-    setText(0, QString::fromLatin1("%1 (%2)").arg(_name).arg(visibleLeafCount));
+    setText(0, QStringLiteral("%1 (%2)").arg(_name).arg(visibleLeafCount));
 }
 
 KWalletContainerItem *KWalletFolderItem::getContainer(KWallet::Wallet::EntryType type)
@@ -97,7 +96,7 @@ KWalletContainerItem *KWalletFolderItem::getContainer(KWallet::Wallet::EntryType
             return ci;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 bool KWalletFolderItem::contains(const QString &key)
@@ -117,13 +116,13 @@ QTreeWidgetItem *KWalletFolderItem::getItem(const QString &key)
             return tmp;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 bool KWalletFolderItem::acceptDrop(const QMimeData *mime) const
 {
-    return mime->hasFormat("application/x-kwallet-entry") ||
-           mime->hasFormat("text/uri-list");
+    return mime->hasFormat(QStringLiteral("application/x-kwallet-entry")) ||
+           mime->hasFormat(QStringLiteral("text/uri-list"));
 }
 
 QString KWalletFolderItem::name() const
@@ -167,7 +166,7 @@ QTreeWidgetItem *KWalletContainerItem::getItem(const QString &key)
             return entryItem;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 /****************
@@ -212,9 +211,9 @@ void KWalletItem::setOpen(bool state)
     if (_open != state) {
         _open = state;
         if (_open) {
-            setIcon(DesktopIcon(QLatin1String("wallet-open")));
+            setIcon(DesktopIcon(QStringLiteral("wallet-open")));
         } else {
-            setIcon(DesktopIcon(QLatin1String("wallet-closed")));
+            setIcon(DesktopIcon(QStringLiteral("wallet-closed")));
         }
     }
 }
@@ -232,7 +231,7 @@ static bool decodeEntry(KWallet::Wallet *_wallet, QDataStream &ds)
     KWallet::Wallet::EntryType et;
     ds >> name;
     if (_wallet->hasEntry(name)) {
-        int rc = KMessageBox::warningContinueCancel(0L, i18n("An entry by the name '%1' already exists. Would you like to continue?", name));
+        int rc = KMessageBox::warningContinueCancel(nullptr, i18n("An entry by the name '%1' already exists. Would you like to continue?", name));
         if (rc == KMessageBox::Cancel) {
             return false;
         }
@@ -256,7 +255,7 @@ static bool decodeFolder(KWallet::Wallet *_wallet, QDataStream &ds)
     QString folder;
     ds >> folder;
     if (_wallet->hasFolder(folder)) {
-        int rc = KMessageBox::warningYesNoCancel(0L, i18n("A folder by the name '%1' already exists.  What would you like to do?", folder), QString(), KStandardGuiItem::cont(), KGuiItem(i18n("Replace")));
+        int rc = KMessageBox::warningYesNoCancel(nullptr, i18n("A folder by the name '%1' already exists.  What would you like to do?", folder), QString(), KStandardGuiItem::cont(), KGuiItem(i18n("Replace")));
         if (rc == KMessageBox::Cancel) {
             return false;
         }
@@ -296,8 +295,8 @@ void KWalletItem::processDropEvent(QDropEvent *e)
         el = dynamic_cast<KWalletEntryList *>(e->source()->parent());
     }
 
-    if (e->mimeData()->hasFormat("application/x-kwallet-folder") ||
-            e->mimeData()->hasFormat("text/uri-list")) {
+    if (e->mimeData()->hasFormat(QStringLiteral("application/x-kwallet-folder")) ||
+            e->mimeData()->hasFormat(QStringLiteral("text/uri-list"))) {
         // FIXME: don't allow the drop if the wallet name is the same
         KWallet::Wallet *_wallet = KWallet::Wallet::openWallet(text(), listWidget()->topLevelWidget()->winId());
         if (!_wallet) {
@@ -309,8 +308,8 @@ void KWalletItem::processDropEvent(QDropEvent *e)
 
         QByteArray data;
 
-        if (e->mimeData()->hasFormat("application/x-kwallet-folder")) {
-            data = e->mimeData()->data("application/x-kwallet-folder");
+        if (e->mimeData()->hasFormat(QStringLiteral("application/x-kwallet-folder"))) {
+            data = e->mimeData()->data(QStringLiteral("application/x-kwallet-folder"));
             e->accept();
         } else { // text/uri-list
             const QList<QUrl> urls = e->mimeData()->urls();
@@ -360,11 +359,11 @@ void KWalletItem::processDropEvent(QDropEvent *e)
 /****************
  *  KWalletEntryList - A listview to store wallet entries
  */
-KWalletEntryList::KWalletEntryList(QWidget *parent, const char *name)
+KWalletEntryList::KWalletEntryList(QWidget *parent, const QString &name)
     : QTreeWidget(parent),
       _wallet(0)
 {
-    setObjectName(QLatin1String(name));
+    setObjectName(name);
     setColumnCount(1);
     setHeaderLabel(i18n("Folders"));
     setRootIsDecorated(true);
@@ -385,8 +384,8 @@ void KWalletEntryList::itemDropped(QDropEvent *e, QTreeWidgetItem *item)
     bool isEntry;
     QByteArray data;
 
-    KWalletEntryList *el = 0L;
-    QTreeWidgetItem *sel = 0L;
+    KWalletEntryList *el = nullptr;
+    QTreeWidgetItem *sel = nullptr;
 
     // We fetch this here because we run an event loop further down which might invalidate this
     Qt::DropAction proposedAction = e->proposedAction();
@@ -408,7 +407,7 @@ void KWalletEntryList::itemDropped(QDropEvent *e, QTreeWidgetItem *item)
         }
     }
 
-    if (e->mimeData()->hasFormat("application/x-kwallet-entry")) {
+    if (e->mimeData()->hasFormat(QStringLiteral("application/x-kwallet-entry"))) {
         //do nothing if we are in the same folder
         if (sel && sel->parent()->parent() ==
                 KWalletEntryList::getItemFolder(item)) {
@@ -416,26 +415,26 @@ void KWalletEntryList::itemDropped(QDropEvent *e, QTreeWidgetItem *item)
             return;
         }
         isEntry = true;
-        data = e->mimeData()->data("application/x-kwallet-entry");
+        data = e->mimeData()->data(QStringLiteral("application/x-kwallet-entry"));
         if (data.isEmpty()) {
             e->ignore();
             return;
         }
         e->accept();
-    } else if (e->mimeData()->hasFormat("application/x-kwallet-folder")) {
+    } else if (e->mimeData()->hasFormat(QStringLiteral("application/x-kwallet-folder"))) {
         //do nothing if we are in the same wallet
         if (this == el) {
             e->ignore();
             return;
         }
         isEntry = false;
-        data = e->mimeData()->data("application/x-kwallet-folder");
+        data = e->mimeData()->data(QStringLiteral("application/x-kwallet-folder"));
         if (data.isEmpty()) {
             e->ignore();
             return;
         }
         e->accept();
-    } else if (e->mimeData()->hasFormat("text/uri-list")) {
+    } else if (e->mimeData()->hasFormat(QStringLiteral("text/uri-list"))) {
         const QList<QUrl> urls = e->mimeData()->urls();
         if (urls.isEmpty()) {
             e->ignore();
@@ -529,15 +528,15 @@ bool KWalletEntryList::existsFolder(const QString &name)
 
 QMimeData *KWalletEntryList::itemMimeData(const QTreeWidgetItem *i) const
 {
-    QMimeData *sd = 0L;
+    QMimeData *sd = nullptr;
     if (i->type() == KWalletEntryItemClass) {
         const KWalletEntryItem *ei = dynamic_cast<const KWalletEntryItem *>(i);
         if (!ei) {
-            return 0L;
+            return nullptr;
         }
         KWalletContainerItem *ci = dynamic_cast<KWalletContainerItem *>(ei->parent());
         if (!ci) {
-            return 0L;
+            return nullptr;
         }
         sd = new QMimeData();
         QByteArray a;
@@ -550,11 +549,11 @@ QMimeData *KWalletEntryList::itemMimeData(const QTreeWidgetItem *i) const
         QByteArray value;
         ei->_wallet->readEntry(i->text(0), value);
         ds << value;
-        sd->setData("application/x-kwallet-entry", a);
+        sd->setData(QStringLiteral("application/x-kwallet-entry"), a);
     } else if (i->type() == KWalletFolderItemClass) {
         const KWalletFolderItem *fi = dynamic_cast<const KWalletFolderItem *>(i);
         if (!fi) {
-            return 0L;
+            return nullptr;
         }
         sd = new QMimeData();
         QByteArray a;
@@ -564,7 +563,7 @@ QMimeData *KWalletEntryList::itemMimeData(const QTreeWidgetItem *i) const
 
         ds << KWALLETFOLDERMAGIC;
         ds << *fi;
-        sd->setData("application/x-kwallet-folder", a);
+        sd->setData(QStringLiteral("application/x-kwallet-folder"), a);
     }
     return sd;
 }
@@ -616,14 +615,14 @@ void KWalletEntryList::dragMoveEvent(QDragMoveEvent *e)
     QTreeWidgetItem *i = itemAt(e->pos());
     e->ignore();
     if (i) {
-        if (e->mimeData()->hasFormat("application/x-kwallet-entry") ||
-                e->mimeData()->hasFormat("text/uri-list")) {
+        if (e->mimeData()->hasFormat(QStringLiteral("application/x-kwallet-entry")) ||
+                e->mimeData()->hasFormat(QStringLiteral("text/uri-list"))) {
             e->accept();
         }
     }
-    if ((e->mimeData()->hasFormat("application/x-kwallet-folder") &&
+    if ((e->mimeData()->hasFormat(QStringLiteral("application/x-kwallet-folder")) &&
             e->source() != viewport()) ||
-            e->mimeData()->hasFormat("text/uri-list")) {
+            e->mimeData()->hasFormat(QStringLiteral("text/uri-list"))) {
         e->accept();
     }
 }
@@ -639,7 +638,7 @@ KWalletFolderItem *KWalletEntryList::getFolder(const QString &name)
             return fi;
         }
     }
-    return 0;
+    return nullptr;
 }
 
 KWalletFolderItem *KWalletEntryList::getItemFolder(QTreeWidgetItem *item)
@@ -652,7 +651,7 @@ KWalletFolderItem *KWalletEntryList::getItemFolder(QTreeWidgetItem *item)
     case KWalletEntryItemClass:
         return dynamic_cast<KWalletFolderItem *>(item->parent()->parent());
     }
-    return 0;
+    return nullptr;
 }
 
 void KWalletEntryList::selectFirstVisible()
@@ -691,7 +690,7 @@ public:
         parent->installEventFilter(this);
     }
 
-    bool eventFilter(QObject * /*watched*/, QEvent *event)
+    bool eventFilter(QObject * /*watched*/, QEvent *event) Q_DECL_OVERRIDE
     {
         if (event->type() == QEvent::KeyPress) {
             QKeyEvent *ke = static_cast<QKeyEvent *>(event);
